;-| Button Remapping |-----------------------------------------------------
; This section lets you remap the player's buttons (to easily change the
; button configuration). The format is:
;   old_button = new_button
; If new_button is left blank, the button cannot be pressed.
[Remap]
x = x
y = y
z = z
a = a
b = b
c = c
s = s
;  Note that if you modify the button remapping scheme here, this character will
; still be able to correctly detect the basic commands of other characters
; complying with the basic command order specified below, as long as their
; buttons haven't been remapped.  But no character (not even one with the same
; remapping scheme, not even another instance of this character) will be able to
; correctly detect this character's commands.  This shouldn't ever result in any
; false positives, but it could delay correct positives, and could erroneously
; make the helper AI activation method trigger a false negative in team simul
; modes, in which case the XOR-ed commands method would be needed to provide
; backup.  But of course, this isn't an issue in any version of Mugen prior to
; version 2002.04.14.

;-| Default Values |-------------------------------------------------------
[Defaults]
; Default value for the "time" parameter of a Command. Minimum 1.
command.time = 15

; Default value for the "buffer.time" parameter of a Command. Minimum 1,
; maximum 30.
command.buffer.time = 1


; These 11 Single Button and Hold Dir commands must be placed here at the top
; of the CMD, above all other commands, and in the standard order shown here,
; in order for the "Compatibly Partnered" version (9742) of the helper AI
; activation method to work with different partners in simul team mode.
; (When the partner is not compatible, then it's best to just use the regular
; version (9741) and rely on the XOR method for backup in case a human
; partner's input turns off the CPU partner's AI.)
;   (Now, even if you do not intend to give your character any custom AI, it
; would still be nice if you would place the commands at the top of your CMD,
; for the sake of other characters which do use this AI activation method.
; And then, define Anim 9741 in your AIR file to indicate to other characters
; that your character is compatible.
;   It may slightly increase the chances of faulty AI activation if the user
; is using characters with a poor implementation of the old humanly-impossible
; commands AI activation method when fighting against your character, but
; other than that, there's really no particular reason not to.  And you can
; change the names of the commands if you want.  For compatibility, all that
; really matters is the "command" and "time" parameters.)
;
; Please don't add any extra definitions for any of these 11 basic command
; names, nor for any of the 7 "hold[button]" command names that follow.
; For example, things like this should be avoided:
;	[Command]
;	name = "z"
;	command = y+b
;	time = 1
; There are several workarounds possible to achieve the same effect.  Please
; feel free to ask me about it if you have any uncertainty.
; Violating this rule would cause the KeyCtrl Helper method and/or the XORed
; Commands method to malfunction, and could also interfere with other future
; applications of this command order standard.
;
;-| Single Button |---------------------------------------------------------
[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

[Command]
name = "start"
command = s
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd";Required (do not remove)
command = /$F
time = 1

[Command]
name = "holdback";Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdup" ;Required (do not remove)
command = /$U
time = 1

[Command]
name = "holddown";Required (do not remove)
command = /$D
time = 1

;-| Hold Button |----------------------------------------------------------
; Please define Anim 74140108 in your AIR file if AND ONLY IF you place these
; 7 Hold Button commands immediately after the 11 Single Button and Hold Dir
; commands at the very top of your CMD list, as demonstrated here.
; In this version of the AI code, these commands are only used by the XOR
; method, and thus are optional.  But there remains a possibility that a
; future version of the helper method might be helped by having these
; commands placed here, and Anim 74140108 would then be used to indicate
; that a partner character has a compatible CMD.

[Command]
name = "holda"
command = /a
time = 1

[Command]
name = "holdb"
command = /b
time = 1

[Command]
name = "holdc"
command = /c
time = 1

[Command]
name = "holdx"
command = /x
time = 1

[Command]
name = "holdy"
command = /y
time = 1

[Command]
name = "holdz"
command = /z
time = 1

[Command]
name = "holdstart"
command = /s
time = 1

;--- None of your own command definitions should be above this line. ---

;-| CPU |--------------------------------------------------------------
; Note that if you make any changes to the basic one-button or recovery
; commands, you'll need to make the same changes to their matching commands here
; and/or in the XOR VarSet controller.  That includes things like, for example:
;  * changing the recovery command to use a different combination of buttons.
;  * renaming the b button command as "d", or the start button command as "s".
;  * switching the button names around, e.g. so button y triggers "a" and button a triggers "y".
;  * having more than one way to trigger the same command name.
; If you understand how the XOR method works, the proper changes should be obvious.
; If you don't understand it, then simply disable the lines in the XOR VarSet
; controller that correspond to the commands you've altered.

[Command]
name = "a2"
command = a
time = 1

[Command]
name = "b2"
command = b
time = 1

[Command]
name = "c2"
command = c
time = 1

[Command]
name = "x2"
command = x
time = 1

[Command]
name = "y2"
command = y
time = 1

[Command]
name = "z2"
command = z
time = 1

[Command]
name = "start2"
command = s
time = 1

[Command]
name = "holdfwd2"
command = /$F
time = 1

[Command]
name = "holdback2"
command = /$B
time = 1

[Command]
name = "holdup2"
command = /$U
time = 1

[Command]
name = "holddown2"
command = /$D
time = 1

[Command]
name = "holda2"
command = /a
time = 1

[Command]
name = "holdb2"
command = /b
time = 1

[Command]
name = "holdc2"
command = /c
time = 1

[Command]
name = "holdx2"
command = /x
time = 1

[Command]
name = "holdy2"
command = /y
time = 1

[Command]
name = "holdz2"
command = /z
time = 1

[Command]
name = "holdstart2"
command = /s
time = 1

[Command]
name = "recovery2"
command = a+b
time = 1

; Here add matching commands for any moves that must never be used randomly
; by the computer, such as suicide moves and super moves, and add the pairs
; to the XOR VarSet controller in State -3.

; If you're desperate to make sure that the AI always gets turned on as soon
; as possible, you can add more equivalents for your own commands here too,
; and add to the XOR VarSet controller's triggers accordingly.

; And of course, if you've run out of unique command labels (Mugen allows
; 128), you can remove as many of these as you want.  You'll of course need
; to modify the XOR VarSet controller's triggers accordingly, but Mugen
; will let you know if you forget to do so. :)


;-| Super Motions |--------------------------------------------------------
;The following two have the same name, but different motion.
;Either one will be detected by a "command = TripleKFPalm" trigger.
;Time is set to 20 (instead of default of 15) to make the move
;easier to do.
;
[Command]
name = "TripleKFPalm"
command = ~D, DF, F, D, DF, F, x
time = 20

[Command]
name = "super1"
command = x+z
time = 1
[Command]
name = "super2"
command = y+z
time = 1
[Command]
name = "super3"
command = x+y+z
time = 1

;-| Special Motions |------------------------------------------------------
[Command]
name = "specialF"
command = /$F,z
[Command]
name = "specialD"
command = /$D,z
[Command]
name = "specialB"
command = /$B,z

;-| Double Tap |-----------------------------------------------------------
[Command]
name = "FF"     ;Required (do not remove)
command = F, F
time = 10

[Command]
name = "BB"     ;Required (do not remove)
command = B, B
time = 10

[Command]
name = "SupahJump"
;command = ~$D, $U
command = ~$D, $U
time = 5
buffer.time = 2

[Command]
name = "ChargedSupahJump"
;command = ~$D, $U
command = ~12$D, $U
time = 5
buffer.time = 2

[Command]
name = "upper_what"
command = ~15$D, $U, x
time = 10
[Command]
name = "upper_what"
command = ~15$D, $U, y
time = 10
[Command]
name = "upper_what"
command = ~15$D, $U, z
time = 10
[Command]
name = "upper_what"
command = ~15$D, $U, a
time = 10
[Command]
name = "upper_what"
command = ~15$D, $U, b
time = 10
[Command]
name = "upper_what"
command = ~15$D, $U, c
time = 10

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "recovery";Required (do not remove)
command = x+y
time = 1
[Command]
name = "throw"
command = x+y
time = 1
[Command]
name = "holdtech"
command = /x+y
time = 1

;-| Dir + Button |---------------------------------------------------------
[Command]
name = "down_a"
command = /$D,a
time = 1

[Command]
name = "down_b"
command = /$D,b
time = 1


;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1, Label]           ;Change Label to any name you want to use to
;                               ;identify the state with.
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = command_name
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; Note: The order of state entry is important.
;   State entry with a certain command must come before another state
;   entry with a command that is the subset of the first.
;   For example, command "fwd_a" must be listed before "a", and
;   "fwd_ab" should come before both of the others.
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in.


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]

; The main purpose of having these next two controllers here at the top of
; StateDef -1 is to make sure the AI helper never changes to a different state,
; nor encounters any VarSets within State -1.
; But they also improve efficiency by preventing Mugen from wasting time
; processing the entire State -1 for the helper.
[State -1, AI Helper Check]
type = ChangeState
trigger1 = IsHelper(9741)
value = 9741

[State -1, AI Helper Check 2]
type = ChangeState
trigger1 = IsHelper(9742)
value = 9742

; This is generally the best place to put most of your AI directives.  For
; example, this controller would only be executed when the CPU is in control:
;
; [State -1, Haha!]
; type = ChangeState
; trigger1 = var(0) ; (Or use "var(58)>0" if you've chosen not to
;                   ; use the Simplifier variable/controller.)
; trigger1 = ctrl
; trigger1 = StateType = S
; trigger1 = MoveType = I
; trigger1 = P2MoveType = H
; trigger1 = NumEnemy = 1
; trigger1 = Enemy,GetHitVar(HitTime) > 60
; trigger1 = PrevStateNo != 195
; trigger1 = Random < 99
; value = 195

; And of course, most human-only command-based ChangeStates also belong
; in State -1.  For example, this move would only be performable by a human:
;
; [State -1, Death Before Dishonor]
; type = ChangeState
; trigger1 = command = "suicide"
; trigger1 = !var(0) ; (Or use "var(58)<1" if you've chosen not to
;                    ; use the Simplifier variable/controller.)
; trigger1 = ctrl
; trigger1 = StateType != A
; trigger1 = MoveType = I
; value = {suicide state number}


;===========================================================================
;This is not a move, but it sets up var(1) to be 1 if conditions are right
;for a combo into a special move (used below).
;Since a lot of special moves rely on the same conditions, this reduces
;redundant logic.
[State -1, Combo condition Reset]
type = VarSet
trigger1 = time >= 0
var(9) = 0

[State -1, Combo condition Check]
type = VarSet
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = (stateno = [200,299]) || (stateno = [400,499])
trigger2 = stateno != 440 ;Except for sweep kick
trigger2 = time;movecontact
trigger3 = stateno = 106
trigger4 = stateno = 40
trigger4 = animtime != 0
var(9) = 1

;===========================================================================
;AI STARTS HERE

[State AI, RESET]
type = VarSet
trigger1 = ailevel=0;fvar(35)=0
trigger2 = random >= (ailevel-8)*2
var(52) = 0
ignorehitpause = 1

[State AI, Consider C.K]
type = VarSet
triggerall = !(var(40) & floor(exp(4*ln(2)) + 0.5))
triggerall = roundstate = 2
triggerall = numenemy
triggerall = var(52) = 0 || random < 80+(fvar(35)*2)
triggerall = ailevel
triggerall = random < (1*(fvar(35)*fvar(35)*fvar(35))) * ifelse(movehit,2,1)
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 150)
triggerall = p2stateno != [5120,5129];[5080,5130]
triggerall = p2bodydist x = [ifelse(p2statetype!=A,-5,-8),25-(9*movecontact)]
triggerall = p2dist y >= -10 - (enemynear,vel y*4)
triggerall = statetype != A
triggerall = ((time >= 7-fvar(35)) && (enemynear,time >= 7-fvar(35))) || random < 10
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 88 || p2movetype = H
trigger1 = ctrl || stateno = 100
trigger1 = prevstateno != 410
trigger2 = stateno = 200
trigger2 = (movecontact)
trigger2 = prevstateno != 410
var(52) = 410
ignorehitpause = 1

[State AI, Consider C.P]
type = VarSet
triggerall = !(var(40) & floor(exp(3*ln(2)) + 0.5))
triggerall = roundstate = 2
triggerall = numenemy
triggerall = var(52) = 0 || random < 80+(fvar(35)*2)
triggerall = ailevel
triggerall = random < (1*(fvar(35)*fvar(35)*fvar(35))) * ifelse(movehit,2,1)
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 150)
triggerall = p2stateno != [5080,5130]
triggerall = p2bodydist x = [ifelse(p2statetype!=A,-5,-8),30-(9*movecontact)]
triggerall = p2dist y >= -50 - (enemynear,vel y*4)
triggerall = ( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <= -50
triggerall = statetype != A
triggerall = ((time >= 7-fvar(35)) && (enemynear,time >= 7-fvar(35))) || random < 10
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 88 || p2movetype = H
trigger1 = ctrl || stateno = 100
trigger2 = stateno = 200 || stateno = 410
trigger2 = (movecontact)
trigger2 = prevstateno != 400
var(52) = 400
ignorehitpause = 1

[State AI, Consider S.P]
type = VarSet
triggerall = !(var(40) & floor(exp(1*ln(2)) + 0.5))
triggerall = roundstate = 2
triggerall = numenemy
triggerall = var(52) = 0 || random < 80+(fvar(35)*2)
triggerall = ailevel
triggerall = random < (1*(fvar(35)*fvar(35)*fvar(35))) * ifelse(movehit,2,1)
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 150)
triggerall = p2stateno != [5080,5130]
triggerall = p2bodydist x = [ifelse(p2statetype!=A,-5,-8),37-(9*movecontact)]
triggerall = p2dist y >= -70 - (enemynear,vel y*4)
triggerall = ( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <= -70
triggerall = statetype != A
triggerall = ((time >= 7-fvar(35)) && (enemynear,time >= 7-fvar(35))) || random < 10
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 88 || p2movetype = H
trigger1 = ctrl || stateno = 100
trigger2 = stateno = 200 || stateno = 410
trigger2 = (movecontact)
trigger2 = prevstateno != 200
var(52) = 200
ignorehitpause = 1

[State AI, Consider S.K]
type = VarSet
triggerall = !(var(40) & floor(exp(2*ln(2)) + 0.5))
triggerall = roundstate = 2
triggerall = numenemy
triggerall = var(52) = 0 || random < 80+(fvar(35)*2)
triggerall = ailevel
triggerall = random < (1*(fvar(35)*fvar(35)*fvar(35))) * ifelse(movehit,2,1)
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 150)
triggerall = p2stateno != [5080,5130]
triggerall = p2bodydist x = [ifelse(p2statetype!=A,-5,-8),32-(9*movecontact)]
triggerall = p2dist y >= -72 - (enemynear,vel y*6)
triggerall = ( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <= -30
triggerall = statetype != A
triggerall = ((time >= 7-fvar(35)) && (enemynear,time >= 7-fvar(35))) || random < 10
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 88 || p2movetype = H
trigger1 = ctrl || stateno = 100
trigger2 = stateno = 200 || stateno = 400
trigger2 = (movecontact)
trigger2 = prevstateno != 210
var(52) = 210
ignorehitpause = 1

[State AI, Consider S.F+P]
type = VarSet
triggerall = !(var(40) & floor(exp(7*ln(2)) + 0.5))
triggerall = roundstate = 2
triggerall = numenemy
triggerall = var(52) = 0 || random < 80+(fvar(35)*2)
triggerall = ailevel
triggerall = random < (1*(fvar(35)*fvar(35)*fvar(35))) * ifelse(movehit,2,1)
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 150)
triggerall = p2stateno != [5080,5130]
triggerall = p2bodydist x = [ifelse(p2statetype!=A,-5,-8),36-(12*movecontact)]
triggerall = p2dist y >= -50 - (enemynear,vel y*10)
triggerall = ( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <= -30
triggerall = statetype != A
triggerall = ((time >= 7-fvar(35)) && (enemynear,time >= 7-fvar(35))) || random < 10
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 88 || p2movetype = H
trigger1 = ctrl || stateno = 100
trigger2 = stateno = 200 || stateno = 400 || stateno = 410
trigger2 = (movecontact)
trigger2 = prevstateno != 210
var(52) = 205
ignorehitpause = 1

[State AI, Consider S.F+K]
type = VarSet
triggerall = !(var(40) & floor(exp(8*ln(2)) + 0.5))
triggerall = roundstate = 2
triggerall = numenemy
triggerall = var(52) = 0 || random < 80+(fvar(35)*2)
triggerall = ailevel
triggerall = random < (1*(fvar(35)*fvar(35)*fvar(35))) * ifelse(movehit||p2statetype=C,2,1)
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 150)
triggerall = p2stateno != [5080,5130]
triggerall = p2bodydist x = [ifelse(p2statetype!=A,-5,-8),70-(9*movecontact)]
triggerall = p2dist y >= -20 - (enemynear,vel y*11)
triggerall = ( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <= -30
triggerall = statetype != A
triggerall = ((time >= 7-fvar(35)) && (enemynear,time >= 7-fvar(35))) || random < 10
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 88 || p2movetype = H
trigger1 = ctrl || stateno = 100
trigger2 = stateno = 200 || stateno = 400 || stateno = 205 || stateno = 410
trigger2 = (movecontact)
trigger2 = prevstateno != 210
var(52) = 215
ignorehitpause = 1

[State AI, Consider S.B+P]
type = VarSet
triggerall = !(var(41) & floor(exp(4*ln(2)) + 0.5))
triggerall = roundstate = 2
triggerall = numenemy
triggerall = var(52) = 0 || random < 80+(fvar(35)*2)
triggerall = ailevel
triggerall = random < (1*(fvar(35)*fvar(35)*fvar(35))) * ifelse(movehit,2,1)
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 150)
triggerall = p2stateno != [5080,5130]
triggerall = p2bodydist x = [ifelse(p2statetype!=A,-5,-8),70-(12*movecontact)]
triggerall = p2dist y >= -64 - (enemynear,vel y*9)
triggerall = ( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <= -90
triggerall = statetype != A
triggerall = ((time >= 7-fvar(35)) && (enemynear,time >= 7-fvar(35))) || random < 10
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 88 || p2movetype = H
trigger1 = ctrl || stateno = 100
trigger2 = stateno = 200 || stateno = 400 || stateno = 410 || stateno = 210
trigger2 = (movecontact)
var(52) = 206
ignorehitpause = 1
[State AI, Consider S.B+P2]
type = VarSet
triggerall = !(var(41) & floor(exp(5*ln(2)) + 0.5))
triggerall = roundstate = 2
triggerall = numenemy
triggerall = var(52) = 0 || random < 80+(fvar(35)*2)
triggerall = ailevel
triggerall = random < (1*(fvar(35)*fvar(35)*fvar(35))) * ifelse(movehit,2,1)
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 150)
triggerall = p2stateno != [5080,5130]
triggerall = p2bodydist x = [ifelse(p2statetype!=A,-5,-8),100-(12*movecontact)]
triggerall = p2dist y >= -100 - (enemynear,vel y*9)
triggerall = ( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <= -90
triggerall = statetype != A
triggerall = ((time >= 7-fvar(35)) && (enemynear,time >= 7-fvar(35))) || random < 10
trigger1 = stateno = 206
trigger1 = (movecontact) || animelemno(0)=6
var(52) = 207
ignorehitpause = 1

[State AI, Consider S.CD]
type = VarSet
triggerall = !(var(40) & floor(exp(0*ln(2)) + 0.5))
triggerall = roundstate = 2
triggerall = numenemy
triggerall = var(52) = 0 || random < 80+(fvar(35)*2)
triggerall = ailevel
triggerall = random < (1*(fvar(35)*fvar(35)*fvar(35))) * ifelse(movehit,2,1)
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 150)
triggerall = p2stateno != [5080,5130]
triggerall = p2bodydist x = [ifelse(p2statetype!=A,-5,-8),110-(9*movecontact)]
triggerall = p2dist y >= -65 - (enemynear,vel y*13)
triggerall = ( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <= -70
triggerall = statetype != A
triggerall = ((time >= 7-fvar(35)) && (enemynear,time >= 7-fvar(35))) || random < 10
triggerall = ( enemynear, vel y <= 0 ) || ( (enemynear, vel y*13) + (enemynear, pos y) <= -13 ) || (p2stateno != [5030,5129])
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 88 || p2movetype = H
trigger1 = ctrl || stateno = 100
trigger2 = stateno = 200 || stateno = 210 || stateno = 400 || stateno = 410
trigger2 = (movecontact)
trigger2 = prevstateno != 200
var(52) = 220
ignorehitpause = 1

[State AI, J.X]
type = Varset
triggerall = !(var(40) & floor(exp(5*ln(2)) + 0.5))
triggerall = roundstate = 2
triggerall = numenemy
triggerall = var(52) = 0 || random < 123
triggerall = ailevel
triggerall = (p2bodydist x = [-20+(vel x*5)+(enemynear,vel x*5),22+(vel x*5)+(enemynear,vel x*5)]) || (abs(p2bodydist x) <= 5 )
triggerall = p2dist y >= -65 + (vel y*6) ; - (enemynear,vel y*6)
triggerall = ( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <=  -70 + (vel y*6); - (enemynear,vel y*6)
triggerall = Statetype = A
triggerall = p2stateno != [5100,5129]
triggerall = p2Statetype = A || vel y >= 0 || p2movetype = A
triggerall = (stateno != [120,169])
triggerall = random < (1*(fvar(35)*fvar(35)*fvar(35)))
triggerall = ((time >= 7-fvar(35)) && (enemynear,time >= 7-fvar(35))) || random < 10
trigger1 = ctrl
var(52) = 600
ignorehitpause = 1

[State AI, J.Y]
type = Varset
triggerall = !(var(40) & floor(exp(6*ln(2)) + 0.5))
triggerall = roundstate = 2
triggerall = numenemy
triggerall = var(52) = 0 || random < 123
triggerall = ailevel
triggerall = (p2bodydist x = [-20+(vel x*6)+(enemynear,vel x*6),40+(vel x*6)+(enemynear,vel x*6)]) || (abs(p2bodydist x) <= 5 )
triggerall = p2dist y >= -55 + (vel y*6) ; - (enemynear,vel y*6)
triggerall = ( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <=  -30 + (vel y*6); - (enemynear,vel y*6)
triggerall = Statetype = A
triggerall = p2stateno != [5100,5129]
triggerall = p2Statetype = A || vel y >= 0 || p2movetype = A
triggerall = (stateno != [120,169])
triggerall = random < (1*(fvar(35)*fvar(35)*fvar(35)))
triggerall = ((time >= 7-fvar(35)) && (enemynear,time >= 7-fvar(35))) || random < 10
trigger1 = ctrl
var(52) = 610
ignorehitpause = 1


[State AI, J.DY]
type = Varset
triggerall = !(var(40) & floor(exp(9*ln(2)) + 0.5))
triggerall = roundstate = 2
triggerall = numenemy
triggerall = var(52) = 0 || random < 123
triggerall = ailevel
triggerall = (p2bodydist x = [-29+(vel x*11)+(enemynear,vel x*11),50+(vel x*11)+(enemynear,vel x*11)]) || (abs(p2bodydist x) <= 5 )
triggerall = p2dist y >= -40 + (vel y*11) ; - (enemynear,vel y*6)
triggerall = Statetype = A
triggerall = p2stateno != [5100,5129]
triggerall = p2Statetype = A || vel y >= 0 || p2movetype = A
triggerall = (stateno != [120,169])
triggerall = random < (1*(fvar(35)*fvar(35)*fvar(35)))
triggerall = ((time >= 7-fvar(35)) && (enemynear,time >= 7-fvar(35))) || random < 10
trigger1 = ctrl
trigger2 = stateno = 600 || stateno = 610
trigger2 = movehit
trigger2 = numtarget
trigger2 = target,statetype=A
var(52) = 615
ignorehitpause = 1

[State AI, J.Z]
type = Varset
triggerall = roundstate = 2
triggerall = numenemy
triggerall = var(52) = 0 || ( (random < 80+fvar(35)) && (var(52)!=[600,650]))
triggerall = ailevel
triggerall = (p2bodydist x = [-20+(vel x*6)+(enemynear,vel x*6),26+(vel x*6)+(enemynear,vel x*6)]) || (abs(p2bodydist x) <= 5 )
triggerall = p2dist y >= -45 + (vel y*6) ; - (enemynear,vel y*6)
triggerall = Statetype = A
triggerall = p2stateno != [5100,5129]
triggerall = p2Statetype = A || vel y >= 0 || p2movetype = A
triggerall = (stateno != [120,169])
triggerall = random < (1*(fvar(35)*fvar(35)*fvar(35)))
triggerall = ((time >= 7-fvar(35)) && (enemynear,time >= 7-fvar(35))) || random < 10
trigger1 = ctrl
trigger2 = stateno = [600,610]
trigger2 = movecontact
var(52) = 1210
ignorehitpause = 1


[State AI, Consider Throwing]
type = VarSet
triggerall = roundstate = 2
triggerall = numenemy
triggerall = var(52) = 0 || random < 900
triggerall = ailevel
triggerall = random < (15*(fvar(35)*fvar(35)))
triggerall = p2stateno != [5080,5130]
triggerall = abs(p2bodydist x) < 6
triggerall = statetype != A
triggerall = p2movetype != H
triggerall = p2statetype != A
triggerall = prevstateno != [800,830]
triggerall = prevstateno != 1350
triggerall = enemynear,prevstateno != [5120,5129]
;triggerall = var(8) = 0
trigger1 = stateno != 40
trigger1 = ctrl
trigger2 = random < 80+fvar(35)
trigger2 = stateno = 200 || stateno = 400 || stateno = 410
trigger2 = movehit
var(52) = 800
ignorehitpause = 1

[State AI, Consider Shoryuken]
type = VarSet
triggerall = !(var(41) & floor(exp(0*ln(2)) + 0.5))
triggerall = roundstate = 2
triggerall = numenemy
triggerall = var(52) = 0 || ( (random < 80+fvar(35)) && (var(52)!=[200,250]) && (var(52)!=[400,650]) )
triggerall = ailevel
triggerall = random < (0.6*(fvar(35)*fvar(35)*fvar(35))) * ifelse(movehit||p2statetype=A,2,1)
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 64) || (enemynear, var(54) > 64)
triggerall = p2stateno != [5080,5130]
triggerall = p2bodydist x <= 260
triggerall = (p2dist y >= -60 - (enemynear,vel y*11)) || (stateno != [200,499])
triggerall = ( enemynear, vel y <= 0 ) || ( (enemynear, vel y*12) + (enemynear, pos y) <= -17 ) || (p2stateno != [5030,5129])
triggerall = statetype != A
triggerall = ((time >= 7-fvar(35)) && (enemynear,time >= 7-fvar(35))) || random < 10
triggerall = (enemynear,GetHitVar(hittime) >= 10 ) || (p2movetype != H) || (p2statetype = A) || (p2stateno != [5000,5025])
triggerall = (prevstateno != [1000,1020])
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 500 || p2movetype = H
trigger1 = var(9)
trigger1 = ctrl || movehit
trigger1 = (stateno != 207 || (stateno = 207 && animelemtime(6)>0))
var(52) = 1000
ignorehitpause = 1
[State AI, Keep on running]
type = VarSet
triggerall = roundstate = 2
triggerall = numenemy
triggerall = ailevel
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 64) || (enemynear, var(54) = [1,64])
triggerall = p2stateno != [5080,5130]
triggerall = p2dist x > -8
triggerall = ( enemynear, vel y <= 0 ) || ( (enemynear, vel y*12) + (enemynear, pos y) <= -17 ) || (p2stateno != [5030,5129])
triggerall = statetype != A
triggerall = ((time >= 7-fvar(35)) && (enemynear,time >= 7-fvar(35))) || random < 10
triggerall = (enemynear,GetHitVar(hittime) >= 10 ) || (p2movetype != H) || (p2statetype = A) || (p2stateno != [5000,5025])
trigger1 = stateno = 1000
var(52) = 1001
ignorehitpause = 1


[State AI, Consider Tatsumaki]
type = VarSet
triggerall = !(var(41) & floor(exp(2*ln(2)) + 0.5))
triggerall = roundstate = 2
triggerall = numenemy
triggerall = var(52) = 0 || ( (random < 80+fvar(35)) && (var(52)!=[200,250]) && (var(52)!=[400,650]) )
triggerall = ailevel
triggerall = random < (0.6*(fvar(35)*fvar(35)*fvar(35))) * ifelse(movehit||p2statetype=A,2,1)
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 64)
triggerall = p2stateno != [5080,5130]
triggerall = (p2bodydist x = [ifelse(p2statetype!=A,-10,-22),200-(13*(movecontact>=1))])
triggerall = (p2dist y >= -150 - (enemynear,vel y*11)) || (stateno != [200,499])
triggerall = ( enemynear, vel y <= 0 ) || ( (enemynear, vel y*12) + (enemynear, pos y) <= -17 ) || (p2stateno != [5030,5129])
triggerall = ( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <= -40
triggerall = statetype != A
triggerall = ((time >= 7-fvar(35)) && (enemynear,time >= 7-fvar(35))) || random < 10
triggerall = (enemynear,GetHitVar(hittime) >= 10 ) || (p2movetype != H) || (p2statetype = A) || (p2stateno != [5000,5025])
triggerall = (prevstateno != [1200,1220])
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 500 || p2movetype = H
trigger1 = var(9)
trigger1 = ctrl || movehit
trigger1 = (stateno != 207 || (stateno = 207 && animelemtime(6)>0))
var(52) = 1200
ignorehitpause = 1
[State AI, Consider doing a further variant]
type = VarSet
triggerall = roundstate = 2
triggerall = numenemy
triggerall = ailevel
triggerall = stateno = 1200
triggerall = time < 7
triggerall = p2bodydist x >= 25
trigger1 = p2bodydist x + (enemynear,vel x*3) >= 80
trigger2 = p2dist y + (enemynear,vel y*3) <= -200
var(52) = 1201
ignorehitpause = 1

[State AI, Consider Quake]
type = VarSet
triggerall = !(var(41) & floor(exp(1*ln(2)) + 0.5))
triggerall = roundstate = 2
triggerall = numenemy
triggerall = var(52) = 0 || ( (random < 80+fvar(35)) && (var(52)!=[200,250]) && (var(52)!=[400,650]) )
triggerall = ailevel
triggerall = random < (0.6*(fvar(35)*fvar(35)*fvar(35))) * ifelse(movehit||p2statetype=S,2,1)
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 64)
triggerall = p2bodydist x <= 620
triggerall = p2stateno != [5120,5129]
triggerall = (p2dist y >= -20 - (enemynear,vel y*11)); || (stateno != [200,499])
triggerall = ( enemynear, vel y <= 0 ) || ( (enemynear, vel y*12) + (enemynear, pos y) <= -17 ) || (p2stateno != [5030,5129])
triggerall = statetype != A
triggerall = ((time >= 7-fvar(35)) && (enemynear,time >= 7-fvar(35))) || random < 10
triggerall = (enemynear,GetHitVar(hittime) >= 10 ) || (p2movetype != H) || (p2statetype = A) || (p2stateno != [5000,5025])
triggerall = (prevstateno != [1100,1120])
triggerall = !numtarget(1100)
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 500 || p2movetype = H
trigger1 = var(9)
trigger1 = ctrl || movecontact
trigger1 = (stateno != 207 || (stateno = 207 && animelemtime(6)>0))
var(52) = 1100
ignorehitpause = 1

[State AI, Consider being really silly]
type = VarSet
triggerall = roundstate = 2
triggerall = numenemy
triggerall = var(52) = 0 || random < 140+fvar(35)
triggerall = ailevel
triggerall = random < (0.35*(fvar(35)*fvar(35)*fvar(35))) * ifelse(movehit||p2statetype=A,2,1) + ((lifemax - life)/8)
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 97)
triggerall = p2stateno != [5080,5130]
triggerall = p2bodydist x <= 150
triggerall = p2dist y >= -145*const(size.yscale) - (enemynear,vel y*3)
;triggerall = p2bodydist x + p2bodydist y = [-24,24]
triggerall = statetype != A
triggerall = power >= 2000
triggerall =(p2movetype = H) || (enemynear, ctrl = 0) || (enemynear, statetype = A) || (random < 80)
triggerall = prevstateno != [2200,2202]
triggerall = p2stateno != [120,156]
triggerall = ( enemynear, vel y <= 0 ) || ( (enemynear, vel y*6) + (enemynear, pos y) <= -4 ) || (p2stateno != [5030,5129])
triggerall = ((time >= 7-fvar(35)) && (enemynear,time >= 7-fvar(35))) || random < 10
triggerall = (enemynear,GetHitVar(hittime) >= 4 ) || (p2movetype != H) || (p2statetype = A) || (p2stateno != [5000,5025])
trigger1 = ctrl || stateno = 100
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 250
trigger2 = var(9)
trigger2 = movehit
trigger2 = (stateno != 207 || (stateno = 207 && animelemtime(6)>0))
trigger3 = stateno = 1201
var(52) = 2200
ignorehitpause = 1

[State AI, Consider blasting Lightning Hadouken]
type = VarSet
triggerall = roundstate = 2
triggerall = numenemy
triggerall = var(52) = 0 || random < 140+fvar(35)
triggerall = ailevel
triggerall = random < (0.35*(fvar(35)*fvar(35)*fvar(35))) * ifelse(movehit||p2statetype=A,2,1) + ((lifemax - life)/8)
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0); || (random < 32)
triggerall = p2stateno != [5080,5130]
triggerall = p2bodydist x <= 130
triggerall = p2dist y >= -50*const(size.yscale) - (enemynear,vel y*7)
triggerall = statetype != A
triggerall = power >= 1000
triggerall =(p2movetype = H) || (enemynear, ctrl = 0) || (enemynear, statetype = A) || (random < 80)
triggerall = prevstateno != [2000,2002]
triggerall = p2stateno != [120,156]
triggerall = ( enemynear, vel y <= 0 ) || ( (enemynear, vel y*6) + (enemynear, pos y) <= -4 ) || (p2stateno != [5030,5129])
triggerall = ((time >= 7-fvar(35)) && (enemynear,time >= 7-fvar(35))) || random < 10
triggerall = (enemynear,GetHitVar(hittime) >= 8 ) || (p2movetype != H) || (p2statetype = A) || (p2stateno != [5000,5025])
trigger1 = ctrl || stateno = 100
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 250
trigger2 = var(9)
trigger2 = movehit
trigger2 = (stateno != 207 || (stateno = 207 && animelemtime(6)>0))
trigger3 = stateno = 1201
var(52) = 2000
ignorehitpause = 1

[State AI, Consider being drunk]
type = VarSet
triggerall = roundstate = 2
triggerall = numenemy
triggerall = var(52) = 0 || random < 140+fvar(35)
triggerall = ailevel
triggerall = random < (0.35*(fvar(35)*fvar(35)*fvar(35))) * ifelse(movehit||p2statetype=A,2,1) + ((lifemax - life)/8)
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0); || (random < 32)
triggerall = p2stateno != [5080,5130]
triggerall = p2bodydist x <= 200
triggerall = p2dist y >= -20*const(size.yscale) - (enemynear,vel y*7)
triggerall = statetype != A
triggerall = power >= 1000
triggerall =(p2movetype = H) || (enemynear, ctrl = 0) || (enemynear, statetype = A) || (random < 80)
triggerall = prevstateno != [2000,2002]
triggerall = p2stateno != [120,156]
triggerall = ( enemynear, vel y <= 0 ) || ( (enemynear, vel y*6) + (enemynear, pos y) <= -4 ) || (p2stateno != [5030,5129])
triggerall = ((time >= 7-fvar(35)) && (enemynear,time >= 7-fvar(35))) || random < 10
triggerall = (enemynear,GetHitVar(hittime) >= 8 ) || (p2movetype != H) || (p2statetype = A) || (p2stateno != [5000,5025])
trigger1 = ctrl || stateno = 100
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 250
trigger2 = var(9)
trigger2 = movehit
trigger2 = (stateno != 207 || (stateno = 207 && animelemtime(6)>0))
var(52) = 2100
ignorehitpause = 1

[State AI, Consider Advancing]
type = VarSet
triggerall = roundstate = 2
triggerall = ailevel
triggerall = var(52) = 0 || random < 80+fvar(35)
triggerall = random < (33*fvar(35)) * ifelse(numhelper(3050),2,1)
triggerall = ((enemynear, ctrl = 0) && p2movetype != A) || (p2movetype = A && (enemynear, facing = facing))
triggerall = (p2stateno != [5080,5130]) || (p2bodydist x = [45,100])
triggerall = p2bodydist x >= 45
triggerall = statetype != A
triggerall = time >= 7-fvar(35) || random < 10
trigger1 = stateno != 40
trigger1 = stateno != 100
trigger1 = ctrl
trigger1 = !moveguarded
var(52) = ifelse(random<200,41,ifelse(random<200&&p2movetype!=H,700,100))
ignorehitpause = 1

[State AI, Consider jumping in]
type = VarSet
triggerall = roundstate = 2
triggerall = numenemy
triggerall = var(52) = 0 || random < 80+fvar(35) + (100*(stateno = 410))
triggerall = ailevel
triggerall = p2stateno != [5080,5130]
;triggerall = statetype != A || stateno = 410
triggerall = p2statetype = A && p2movetype = H
triggerall = (enemynear, pos y <= -45) || (stateno = 410)
trigger1 = ctrl || stateno = 100 || stateno = 40
;trigger2 = stateno = 410
;trigger2 = movecontact
var(52) = ifelse(p2bodydist x>=20,ifelse(p2bodydist x>=160,44,41),42)
ignorehitpause = 1

[State AI, Consider Moving Around Evasively]
type = VarSet
triggerall = roundstate = 2
triggerall = ailevel
triggerall = var(52) = 0 || random < 80+fvar(35)
triggerall = random < (0.21*(fvar(35)*fvar(35)*fvar(35))) * ifelse(moveguarded||inguarddist,2,1)
;triggerall = p2bodydist x >= 45
triggerall = (p2movetype != H) || (p2stateno = [120,159])
triggerall = statetype != A
triggerall = time >= 7-fvar(35) || random < 10
triggerall = prevstateno != [700,701]
trigger1 = stateno != 40
trigger1 = stateno != 100
trigger1 = stateno != 20
trigger1 = stateno != [10,12]
trigger1 = ctrl
trigger2 = var(9)
trigger2 = moveguarded
trigger2 = power >= 1500
trigger2 = p2movetype = A
trigger3 = stateno = 151 || stateno = 153
trigger3 = power >= ifelse(life<p2life,500,1500)
var(52) = ifelse(command="holdback",701,700)
ignorehitpause = 1

[State AI, Consider Evading Projectiles]
type = VarSet
triggerall = numenemy
triggerall = roundstate = 2
triggerall = ailevel
triggerall = var(52) = 0 || random < 80+fvar(35)
triggerall = random < (8*fvar(35))
triggerall = enemynear, var(54) = [1,64]
triggerall = p2bodydist x >= 45
triggerall = frontedgebodydist >= 60
triggerall = statetype != A
triggerall = time >= 7-fvar(35) || random < 10
trigger1 = stateno != 40
trigger1 = stateno != 100
trigger1 = stateno != [150,159]
trigger1 = ctrl
var(52) = 700
;var(52) = ifelse(random<200&&stateno!=100,41,100)
ignorehitpause = 1

[State AI, Guard S]
type = ChangeState
triggerall = roundstate = 2
triggerall = ailevel
triggerall = stateno != 40
triggerall = random < (1*(fvar(35)*fvar(35)*fvar(35)))
triggerall = (fvar(35)) && (StateType != A) && (Ctrl) && (EnemyNear, Facing != Facing) && (var(50)<40)
triggerall = ((time >= 7-fvar(35)) && (enemynear,time >= 14-(fvar(35)*2)))
trigger1 = (P2StateType != C) && (((P2MoveType = A) && (inguarddist)) || (EnemyNear, NumProj > 0))
;value = 130
value = ifelse(random<50&&(stateno!=[120,159])&&(stateno!=[700,705]),ifelse(random<500,700,701),130)

[State AI, Guard L]
type = ChangeState
triggerall = roundstate = 2
triggerall = ailevel
triggerall = stateno != 40
triggerall = random < (1*(fvar(35)*fvar(35)*fvar(35)))
triggerall = (fvar(35)) && (StateType != A) && (Ctrl) && (EnemyNear, Facing != Facing) && (var(50)<40)
triggerall = ((time >= 7-fvar(35)) && (enemynear,time >= 14-(fvar(35)*2)))
trigger1 = (P2StateType = C) && (((P2MoveType = A) && (inguarddist)) || (EnemyNear, NumProj > 0))
;value = 131
value = ifelse(random<50&&(stateno!=[120,159])&&(stateno!=[700,705]),ifelse(random<500,700,701),131)


;===========================================================================
;AI END HERE

[State -1, Super]
type = ChangeState
value = 2200
triggerall = (ailevel < 5 && command = "super3") || var(52) = 2200
;triggerall = command = "holddown" || statetype = A
triggerall = power >= 2000
trigger1 = var(9)
trigger2 = stateno = 2000
trigger2 = anim = 2001
trigger3 = stateno = 1100

[State -1, Super]
type = ChangeState
value = 2100
triggerall = (ailevel < 5 && command = "super2") || var(52) = 2100
;triggerall = command = "holddown" || statetype = A
triggerall = power >= 1000
trigger1 = var(9)
trigger2 = stateno = 2000
trigger2 = anim = 2001
trigger3 = stateno = 1100
;trigger2 = statetype = A
;trigger2 = ctrl || (stateno = [600,610])
;trigger3 = stateno = 2000
;trigger3 = time >= 6
;trigger4 = stateno = 1201
;trigger5 = stateno = 1100
;trigger5 = movecontact

[State -1, Super]
type = ChangeState
value = 2000
triggerall = (ailevel < 5 && command = "super1") || var(52) = 2000
triggerall = power >= 1000
trigger1 = var(9)
trigger2 = stateno = 1100

[State -1, Shoryuken]
type = ChangeState
value = 1100
triggerall = (ailevel < 5 && command = "specialD") || var(52) = 1100
trigger1 = var(9)

[State -1, Hadouken]
type = ChangeState
value = 1000
triggerall = (ailevel < 5 && ifelse((anim !=[5,6]),command = "specialF",command="specialB")) || var(52) = 1000
trigger1 = var(9)

[State -1, Tatsumaki]
type = ChangeState
value = 1200
triggerall = (ailevel < 5 && ifelse((anim !=[5,6]),command = "specialB",command="specialF")) || var(52) = 1200
trigger1 = var(9)

[State -1, Aerial Tatsumaki]
type = ChangeState
value = 1300
triggerall = (ailevel < 5 && command = "z") || var(52) = 1300
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 600 || stateno = 610

[State -1, Throw]
type = ChangeState
value = 800
triggerall = (ailevel < 5 && command = "throw") || var(52) = 800
trigger1 = var(9)
trigger1 = stateno != 220

[State -1, N.C]
type = ChangeState
value = 220
triggerall = (ailevel < 5 && command = "z") || var(52) = 220
trigger1 = var(9)
trigger1 = stateno != 220

[State -1, Counter->A.C]
type = ChangeState
value = 731
triggerall = (ailevel < 5 && command = "z") || var(52) = [730,734]
triggerall = power >= 500
trigger1 = stateno = 154
trigger1 = time = [0,3]

[State -1, Counter->C]
type = ChangeState
value = 730
triggerall = (ailevel < 5 && command = "z") || var(52) = [730,734]
triggerall = power >= 500
trigger1 = stateno = 150 || stateno = 152
trigger1 = time = [0,3]

[State -1, Dodge Forward]
type = ChangeState
value = 700
triggerall = (ailevel < 5 && command = "a" && command != "holdback") || var(52) = 700
triggerall = statetype != A
trigger1 = ctrl
trigger2 = power >= 500
trigger2 = var(9)
trigger2 = stateno != 220
trigger3 = power >= 500
trigger3 = stateno = [150,153]
trigger3 = statetype != A

[State -1, Dodge Backward]
type = ChangeState
value = 701
triggerall = (ailevel < 5 && command = "a" && command = "holdback") || var(52) = 701
triggerall = statetype != A
trigger1 = ctrl
trigger2 = power >= 500
trigger2 = var(9)
trigger2 = stateno != 220
trigger3 = power >= 500
trigger3 = stateno = [150,153]
trigger3 = statetype != A

;===========================================================================
;---------------------------------------------------------------------------
;Run Fwd
;_bV
[State -1, Run Fwd]
type = ChangeState
value = 100
triggerall = (ailevel < 5 && command = "FF") || var(52) = 100
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Run Back
;ރ_bV
[State -1, Run Back]
type = ChangeState
value = 105
triggerall = (ailevel < 5 && command = "BB") || var(52) = 105
trigger1 = statetype = S
trigger1 = ctrl

;===========================================================================
;---------------------------------------------------------------------------
;Stand Light Punch
;Stand Light Punch
[State -1, Stand Backward Punch]
type = ChangeState
value = 206
triggerall = (ailevel < 5 && (command = "x" && command = "holdback")) || var(52) = 206
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = 200 || stateno = 400 || stateno = 410 || stateno = 210
trigger2 = (animtime >= -6) || movecontact
trigger3 = stateno = 106

[State -1, Stand Backward Punch]
type = ChangeState
value = 207
triggerall = (ailevel < 5 && (command = "x")) || var(52) = 207
trigger1 = stateno = 206
trigger1 = animelemtime(5) > 0 || movecontact
trigger1 = animelemtime(7) < 0


;Stand Light Punch
[State -1, Stand Forward Punch]
type = ChangeState
value = 205
triggerall = (ailevel < 5 && (command = "x" && (command = "holdfwd" || (stateno = [200,400])))) || var(52) = 205
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = 200 || stateno = 400 || stateno = 410 || stateno = 210
trigger2 = (animtime >= -6) || movecontact
trigger3 = stateno = 106

[State -1, Stand Punch]
type = ChangeState
value = 200
triggerall = (ailevel < 5 && (command = "x" && command != "holddown")) || var(52) = 200
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = 410
trigger2 = (animtime >= -6) || movecontact
trigger3 = stateno = 106

[State -1, Stand Forward Kick]
type = ChangeState
value = 215
triggerall = (ailevel < 5 && (command = "y" && command = "holdfwd")) || var(52) = 215
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = 200 || stateno = 400 || stateno = 410 || stateno = 210 || stateno = 205
trigger2 = (animtime >= -6) || movecontact
trigger3 = stateno = 106


;Stand Light Punch
[State -1, Stand Kick]
type = ChangeState
value = 210
triggerall = (ailevel < 5 && (command = "y" && command != "holddown")) || var(52) = 210
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = 200 || stateno = 400 || stateno = 410
trigger2 = (animtime >= -6) || movecontact
trigger3 = stateno = 106

[State -1, Taunt]
type = ChangeState
value = 195
triggerall = (command = "start") || (var(52) = [195,196]) || (ailevel && winko && !var(48))
triggerall = stateno != 195
trigger1 = statetype != A
trigger1 = ctrl


;---------------------------------------------------------------------------
;Crouching Light Punch
[State -1, Crouching Punch]
type = ChangeState
value = 400
triggerall = (ailevel < 5 && (command = "x" && command = "holddown")) || var(52) = 400
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = 410
trigger2 = (animtime >= -6) || movecontact
trigger3 = stateno = 106

;---------------------------------------------------------------------------
;Crouching Light Punch
[State -1, Crouching Kick]
type = ChangeState
value = 410
triggerall = (ailevel < 5 && (command = "y" && command = "holddown")) || var(52) = 410
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = 106

;---------------------------------------------------------------------------
;Jump Light Punch
[State -1, Jump Punch]
type = ChangeState
value = 600
triggerall = (ailevel < 5 && command = "x") || var(52) = 600
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 610
trigger2 = time >= 7
trigger2 = prevstateno != 600

;---------------------------------------------------------------------------
;Drop Kick
[State -1, Drop Kick]
type = ChangeState
value = 615
triggerall = (ailevel < 5 && (command = "y" && command = "holddown")) || var(52) = 615
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 600 || stateno = 610
trigger2 = movecontact
trigger2 = numtarget
trigger2 = target,statetype = A

;---------------------------------------------------------------------------
;Jump Light Punch
[State -1, Jump Kick]
type = ChangeState
value = 610
triggerall = (ailevel < 5 && command = "y") || var(52) = 610
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 600
trigger2 = time >= 7
trigger2 = prevstateno != 610


;---------------------------------------------------------------------------
;Jump Light Punch
[State -1, Jump Kick]
type = ChangeState
value = 610
triggerall = (ailevel < 5 && command = "y") || var(52) = 610
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 600
trigger2 = time >= 7
trigger2 = prevstateno != 610

;[State -1, TAG]
;type = TagIn
;stateno = 4000
;partnerstateno = 4012
;triggerall = command = "x"
;triggerall = statetype != A
;triggerall = ctrl
;triggerall = numpartner
;trigger1 = partner,alive
;trigger1 = partner,stateno = 4011
;trigger1 = partner,time >= 120
;ctrl = 0

[State -1, Air combo lol]
type = ChangeState
value = ifelse(statetype=A,45,40)
triggerall = (command = "holdup") || var(52) = [40,45]
trigger1 = ailevel
trigger1 = stateno != 40
trigger1 = statetype != A
trigger1 = ctrl
;trigger2 = stateno = 100
trigger2 = stateno = 207
trigger2 = numtarget
trigger2 = target,statetype=A
trigger2 = movehit
